==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceSimpleAd.md <==
# AwsDirectoryServiceSimpleAd


```text
aws-20210730/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceSimpleAd
```

```text
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceSimpleAd')
```



| Illustration | AwsDirectoryServiceSimpleAd | AwsDirectoryServiceSimpleAdCard | AwsDirectoryServiceSimpleAdGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceSimpleAd.png) | ![illustration for AwsDirectoryServiceSimpleAd](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceSimpleAd.Local.png) | ![illustration for AwsDirectoryServiceSimpleAdCard](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceSimpleAdCard.Local.png) | ![illustration for AwsDirectoryServiceSimpleAdGroup](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceSimpleAdGroup.Local.png) |




## AwsDirectoryServiceSimpleAd

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsDirectoryServiceSimpleAd
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceSimpleAd')

' renders the element
AwsDirectoryServiceSimpleAd('AwsDirectoryServiceSimpleAd', 'Aws Directory Service Simple Ad', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsDirectoryServiceSimpleAd
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceSimpleAd')

' renders the element
AwsDirectoryServiceSimpleAd('AwsDirectoryServiceSimpleAd', 'Aws Directory Service Simple Ad', 'an optional tech label')
@enduml
```

## AwsDirectoryServiceSimpleAdCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsDirectoryServiceSimpleAdCard
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceSimpleAd')

' renders the element
AwsDirectoryServiceSimpleAdCard('AwsDirectoryServiceSimpleAdCard', 'Aws Directory Service Simple Ad Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsDirectoryServiceSimpleAdCard
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceSimpleAd')

' renders the element
AwsDirectoryServiceSimpleAdCard('AwsDirectoryServiceSimpleAdCard', 'Aws Directory Service Simple Ad Card', 'an optional description')
@enduml
```

## AwsDirectoryServiceSimpleAdGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsDirectoryServiceSimpleAdGroup
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceSimpleAd')

' renders the element
AwsDirectoryServiceSimpleAdGroup('AwsDirectoryServiceSimpleAdGroup', 'Aws Directory Service Simple Ad Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsDirectoryServiceSimpleAdGroup
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceSimpleAd')

' renders the element
AwsDirectoryServiceSimpleAdGroup('AwsDirectoryServiceSimpleAdGroup', 'Aws Directory Service Simple Ad Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-20210730/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceSimpleAd.md <==
# AwsDirectoryServiceSimpleAd


```text
aws-20210730/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceSimpleAd
```

```text
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceSimpleAd')
```



| Illustration | AwsDirectoryServiceSimpleAd | AwsDirectoryServiceSimpleAdCard | AwsDirectoryServiceSimpleAdGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceSimpleAd.png) | ![illustration for AwsDirectoryServiceSimpleAd](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceSimpleAd.Local.png) | ![illustration for AwsDirectoryServiceSimpleAdCard](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceSimpleAdCard.Local.png) | ![illustration for AwsDirectoryServiceSimpleAdGroup](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceSimpleAdGroup.Local.png) |




## AwsDirectoryServiceSimpleAd

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsDirectoryServiceSimpleAd
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceSimpleAd')

' renders the element
AwsDirectoryServiceSimpleAd('AwsDirectoryServiceSimpleAd', 'Aws Directory Service Simple Ad', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsDirectoryServiceSimpleAd
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceSimpleAd')

' renders the element
AwsDirectoryServiceSimpleAd('AwsDirectoryServiceSimpleAd', 'Aws Directory Service Simple Ad', 'an optional tech label')
@enduml
```

## AwsDirectoryServiceSimpleAdCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsDirectoryServiceSimpleAdCard
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceSimpleAd')

' renders the element
AwsDirectoryServiceSimpleAdCard('AwsDirectoryServiceSimpleAdCard', 'Aws Directory Service Simple Ad Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsDirectoryServiceSimpleAdCard
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceSimpleAd')

' renders the element
AwsDirectoryServiceSimpleAdCard('AwsDirectoryServiceSimpleAdCard', 'Aws Directory Service Simple Ad Card', 'an optional description')
@enduml
```

## AwsDirectoryServiceSimpleAdGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsDirectoryServiceSimpleAdGroup
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceSimpleAd')

' renders the element
AwsDirectoryServiceSimpleAdGroup('AwsDirectoryServiceSimpleAdGroup', 'Aws Directory Service Simple Ad Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsDirectoryServiceSimpleAdGroup
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceSimpleAd')

' renders the element
AwsDirectoryServiceSimpleAdGroup('AwsDirectoryServiceSimpleAdGroup', 'Aws Directory Service Simple Ad Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
